# Generated by roxygen2: do not edit by hand

export(armRatioCI)
export(asymmetry)
export(asymmetryA2)
export(citrusMarkPos)
export(citrusSize)
export(fillMarkInfo)
export(fillMarkInfo2)
export(genBankReadIF)
export(make.uniqueIF)
export(makedfMarkColorMycolors)
export(mapGGChr)
export(mapGGChrMark)
export(markOverCMA)
export(namesToColumns)
export(perMark)
export(plotIdiograms)
export(posCalc)
export(robert)
export(runBoard)
export(swapChrRegionDfSizeAndMarks)
import(crayon)
importFrom(dplyr,"%>%")
importFrom(dplyr,across)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,everything)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,summarise)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,axis)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,polygon)
importFrom(graphics,rug)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(plyr,rbind.fill)
importFrom(rlang,.data)
importFrom(scales,alpha)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(tidyr,as_tibble)
importFrom(tidyr,fill)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest)
importFrom(utils,install.packages)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
